@@ -44,6 +44,8 @@
 #' @param strip.width if \code{ddf.obj}, above, is \code{NULL}, then this is where the strip width is specified (i.e. for a strip transect survey). This is sometimes (and more correctly) referred to as the half-width, i.e. right truncation minus left truncation.
 #' @param segment.area if `NULL` (default) segment areas will be calculated by multiplying the `Effort` column in `segment.data` by the (right minus left) truncation distance for the `ddf.obj` or by `strip.width`. Alternatively a vector of segment areas can be provided (which must be the same length as the number of rows in `segment.data`) or a character string giving the name of a column in `segment.data` which contains the areas. If \code{segment.area} is specified it takes precident.
 #' @param weights weights for each observation used in model fitting. The default, \code{weights=NULL}, weights each observation by its area (see Details). Setting a scalar value (e.g. \code{weights=1}) all observations are equally weighted.
+#' @param transect type of transect (\code{"line"}, the default or \code{"point"}). This is overridden by the detection function transect type, this is usually only necessary when no detection function is specified.
+#' @param method The smoothing parameter estimation method. Default is \code{"REML"}, using REstricted Maximum Likelihood. See \code{\link{gam}} for other options. Ignored for \code{engine="glm"}.
 #' @param \dots anything else to be passed straight to \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}}/\code{\link{bam}}.
 #' @return a \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}} object, with an additional element, \code{ddf} which holds the detection function object.
 #' @author David L. Miller
@@ -90,10 +92,11 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
                 engine="gam", convert.units=1,
                 family=quasipoisson(link="log"), group=FALSE, gamma=1.4,
                 control=list(keepData=TRUE), availability=1, strip.width=NULL,
-                segment.area=NULL, weights=NULL, ...){
-  
+                segment.area=NULL, weights=NULL, transect="line", method="REML",
+                ...){
+
   stopifnot(engine %in% c("gam","bam","glm","gamm"))
-  
+
   # if we have a model fitted using Distance, then just pull out the
   # ddf component
   if(!is.null(ddf.obj)){
@@ -118,10 +121,19 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
   #    bad happens
   check.cols(ddf.obj, segment.data, observation.data, strip.width, segment.area)
 
+  # what is the transect type?
+  if(!is.null(ddf.obj)){
+    if(ddf.obj$meta.data$point){
+      transect <- "point"
+    }else{
+      transect <- "line"
+    }
+  }
+
   ## build the data
   dat <- make.data(response, ddf.obj, segment.data, observation.data,
                    group, convert.units, availability, strip.width,
-                   segment.area, family)
+                   segment.area, family, transect)
 
   ## if we are not modelling density/presence, then add in the offset
   ##  to the formula
@@ -154,7 +166,14 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
                data    = dat,
                gamma   = gamma,
                weights = weights,
-               control = control, ...)
+               control = control,
+               method  = method,
+               ...)
+
+  # glm doesn't understand method= in the way we think of it
+  if(engine == "glm"){
+    args$method <- NULL
+  }
 
   fit <- withCallingHandlers(do.call(engine, args),
                              warning=matrixnotposdef.handler)
